==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/view/schvalenidochazky.php <==
<?php
/**
 * stanislav.elbl, 17.11.2014
 * formular pro schvaleni dochazky jedne osoby
 */

namespace Ron\RonPortal;

use Ron\MVC\Model;
use Ron\StringUtils;

global $STR_ZpracovanoDo;   // kompat
global $STR_ZkontrolovanoDo;// kompat
global $STR_SchvalenoDo;    // kompat

/** @var Obdobi $obdobi_obj */
$obdobi_obj = Model::getInstance() ->getData('obdobi');

/** @var int $datumZpracovaniDochazky */
$datumZpracovaniDochazky = Model::getInstance() ->getData('datumzpracovanidochazky');

/** @var int $datumPredplneni */
$datumPredplneni = $datumZpracovaniDochazky;
if ($datumPredplneni < $obdobi_obj->zacatek) $datumPredplneni = 0;
else if ($datumPredplneni > $obdobi_obj->konec) $datumPredplneni = $obdobi_obj->konec;

$datumPredplneniStr =  $datumPredplneni ? date('j.n.Y', $datumPredplneni) : '';

?>

<div id="schvaleni_dialog" style="display:none" title="<?= \Ron\ronText('Schvalovani') ?>">

    <input type="hidden" id="schvaleni_idpp" name="idpp" value="" />
    <input type="hidden" id="schvaleni_obdobi" name="obdobi" value="<?= $obdobi_obj ->zacatek ?>" />

    <div style="position:relative">
        <div id="schvaleni_waitmessage" class="dialogwaitmessage"><?= \Ron\ronText('Probiha_nacitani') ?></div>
        <!--<div id="schvaleni_errormessage" class="dialogwaitmessage" style="display:none"></div>-->

        <table id="schvaleni_osoby_form" >

            <tr>
                <td class='formtablecaption'><?= \Ron\ronText('Obdobi') ?></td>
                <td colspan="2"><strong><span id="schvaleni_popisobdobi"><?= StringUtils::htmlTextConvert($obdobi_obj ->popis) ?></span></strong></td>
            </tr>
            <tr>
                <td class='formtablecaption'><?= \Ron\ronText('Osoba') ?></td>
                <td colspan="2"><strong><span id="schvaleni_jmeno"></span></strong></td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2"><?= \Ron\ronText('Datum_posledniho_zpracovani') ?> <?= date('j.n.Y', $datumZpracovaniDochazky) ?></td>
            </tr>

            <tr>
                <td></td><td>&nbsp;</td><td></td>
            </tr>

            <tr id="schvaleni_row_schvaleni1">
                <td class='formtablecaption textschvaleni1'><label for="schvaleni_zpracovanodo"><?= $STR_ZpracovanoDo ?: \Ron\ronText('Dochazka_schvaleni_1_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_zpracovanodo" name="schvaleni_zpracovanodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_zpracovanobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_zpracovanodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                            if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_zpracovanodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td style="text-align:right">
                    <span id="schvaleni_zpracoval"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_schvaleni2">
                <td class='formtablecaption textschvaleni2'><label for="schvaleni_zkontrolovanodo"><?= $STR_ZkontrolovanoDo ?: \Ron\ronText('Dochazka_schvaleni_2_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_zkontrolovanodo" name="schvaleni_zkontrolovanodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_zkontrolovanobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_zkontrolovanodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                        if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_zkontrolovanodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td style="text-align:right">
                    <span id="schvaleni_zkontroloval"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_schvaleni3">
                <td class='formtablecaption textschvaleni3'><label for="schvaleni_schvalenodo"><?= $STR_SchvalenoDo ?: \Ron\ronText('Dochazka_schvaleni_3_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_schvalenodo" name="schvaleni_schvalenodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_schvalenobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_schvalenodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                        if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_schvalenodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td style="text-align:right">
                    <span id="schvaleni_schvalil"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_mzdy">
                <td></td>
                <td colspan="2"><span id="schvaleni_zpracovanovemzdach"><?= \Ron\ronText('Zpracovano_ve_mzdach') ?></span></td>
            </tr>

            <tr id="schvaleni_row_poznamka">
                <td class="formtablecaption"><label for="schvaleni_poznamka"><?= \Ron\ronText('Poznamka') ?></label></td>
                <td colspan="2">
                    <textarea id="schvaleni_poznamka" name="poznamka" cols="70" rows="8"></textarea>
                </td>
            </tr>
        </table>
    </div>

    <DIV class="buttons align-center">
        <?php if (!$obdobi_obj->uzavreno) { ?>
            <input type="submit" id="btnSchvaleniOK" class="submitbutton" value="<?= \Ron\ronText('Provest') ?>" />
        <?php } ?>
        <input type="button" id="btnStornoSchvaleni" class="button" value="<?= \Ron\ronText('Cancel') ?>" />
    </DIV>
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2310_174.zip: ronportal/view/schvalenidochazky.php <==
<?php
/**
 * stanislav.elbl, 17.11.2014
 * formular pro schvaleni dochazky jedne osoby
 */

namespace RonPortal;

use Ron\MVC\Model;
use Ron\StringUtils;

global $STR_ZpracovanoDo;   // kompat
global $STR_ZkontrolovanoDo;// kompat
global $STR_SchvalenoDo;    // kompat

/** @var Obdobi $obdobi_obj */
$obdobi_obj = Model::getInstance() ->getData('obdobi');

/** @var int $datumZpracovaniDochazky */
$datumZpracovaniDochazky = Model::getInstance() ->getData('datumzpracovanidochazky');

/** @var int $datumPredplneni */
$datumPredplneni = $datumZpracovaniDochazky;
if ($datumPredplneni < $obdobi_obj->zacatek) $datumPredplneni = 0;
else if ($datumPredplneni > $obdobi_obj->konec) $datumPredplneni = $obdobi_obj->konec;

$datumPredplneniStr =  $datumPredplneni ? date('j.n.Y', $datumPredplneni) : '';

?>

<div id="schvaleni_dialog" class="d-none" title="<?= \Ron\ronText('Schvalovani') ?>">

    <input type="hidden" id="schvaleni_idpp" name="idpp" value="" />
    <input type="hidden" id="schvaleni_obdobi" name="obdobi" value="<?= $obdobi_obj ->zacatek ?>" />
    <?= Security::csrfHiddenInput(['id' => 'schvaleni_csrfkey']) ?>

    <div class="position-relative">
        <div id="schvaleni_waitmessage" class="dialogwaitmessage"><?= \Ron\ronText('Probiha_nacitani') ?></div>
        <table id="schvaleni_osoby_form" >

            <tr>
                <td class='formtablecaption'><?= \Ron\ronText('Obdobi') ?></td>
                <td colspan="2"><strong><span id="schvaleni_popisobdobi"><?= StringUtils::htmlTextConvert($obdobi_obj ->popis) ?></span></strong></td>
            </tr>
            <tr>
                <td class='formtablecaption'><?= \Ron\ronText('Osoba') ?></td>
                <td colspan="2"><strong><span id="schvaleni_jmeno"></span></strong></td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2"><?= \Ron\ronText('Datum_posledniho_zpracovani') ?> <?= date('j.n.Y', $datumZpracovaniDochazky) ?></td>
            </tr>

            <tr>
                <td></td><td>&nbsp;</td><td></td>
            </tr>

            <tr id="schvaleni_row_schvaleni1">
                <td class='formtablecaption textschvaleni1'><label for="schvaleni_zpracovanodo"><?= $STR_ZpracovanoDo ?: \Ron\ronText('Dochazka_schvaleni_1_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_zpracovanodo" name="schvaleni_zpracovanodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_zpracovanobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_zpracovanodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                            if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_zpracovanodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td class="align-right">
                    <span id="schvaleni_zpracoval"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_schvaleni2">
                <td class='formtablecaption textschvaleni2'><label for="schvaleni_zkontrolovanodo"><?= $STR_ZkontrolovanoDo ?: \Ron\ronText('Dochazka_schvaleni_2_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_zkontrolovanodo" name="schvaleni_zkontrolovanodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_zkontrolovanobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_zkontrolovanodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                        if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_zkontrolovanodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td class="align-right">
                    <span id="schvaleni_zkontroloval"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_schvaleni3">
                <td class='formtablecaption textschvaleni3'><label for="schvaleni_schvalenodo"><?= $STR_SchvalenoDo ?: \Ron\ronText('Dochazka_schvaleni_3_do') ?></label></td>
                <td>
                    <input type="text" id="schvaleni_schvalenodo" name="schvaleni_schvalenodo" value="" class= "app-input inputDate" maxlength="10" size="10"
                           data-roncalendar-mindate="<?= date('j.n.Y', $obdobi_obj ->zacatek) ?>" data-roncalendar-maxdate="<?= $datumPredplneniStr ?>"
                           data-datum-predplneni="<?= $datumPredplneniStr ?>"/>

                    <span id="schvaleni_schvalenobtn"> <!-- zajistuje skryvani podle prav -->
                        <i class="inline-glyph glyph-button fa glyph-calendar showcalendar"  data-roncalendar-inputname="schvaleni_schvalenodo"></i>
                        <?php // odkaz pro predplneni do konce obdobi/posledniho zpracovani
                        if ($datumPredplneniStr) { ?>
                            &nbsp;&nbsp; <a href="#" data-predvyplnit-input="schvaleni_schvalenodo"><?= $datumPredplneniStr ?></a>
                        <?php } ?>
                    </span>
                </td>
                <td class="align-right">
                    <span id="schvaleni_schvalil"></span>
                </td>
            </tr>

            <tr id="schvaleni_row_mzdy">
                <td></td>
                <td colspan="2"><span id="schvaleni_zpracovanovemzdach"><?= \Ron\ronText('Zpracovano_ve_mzdach') ?></span></td>
            </tr>

            <tr id="schvaleni_row_poznamka">
                <td class="formtablecaption"><label for="schvaleni_poznamka"><?= \Ron\ronText('Poznamka') ?></label></td>
                <td colspan="2">
                    <textarea id="schvaleni_poznamka" name="poznamka" cols="70" rows="8"></textarea>
                </td>
            </tr>
        </table>
    </div>

    <DIV class="buttons align-center">
        <?php if (!$obdobi_obj->uzavreno) { ?>
            <input type="submit" id="btnSchvaleniOK" class="submitbutton" value="<?= \Ron\ronText('Provest') ?>" />
        <?php } ?>
        <input type="button" id="btnStornoSchvaleni" class="button" value="<?= \Ron\ronText('Cancel') ?>" />
    </DIV>
</div>
